@@ -1,20 +1,20 @@
 ;;; sisyphus.el --- Create releases of Emacs packages  -*- lexical-binding:t -*-
 
-;; Copyright (C) 2022-2025 Jonas Bernoulli
+;; Copyright (C) 2022-2026 Jonas Bernoulli
 
 ;; Author: Jonas Bernoulli <emacs.sisyphus@jonas.bernoulli.dev>
 ;; Homepage: https://github.com/magit/sisyphus
 ;; Keywords: git tools vc
 
-;; Package-Version: 0.3.1
-;; Package-Revision: v0.3.1-0-g8fe6d76d3d31
+;; Package-Version: 0.4.0
+;; Package-Revision: v0.4.0-0-g7774ea7030fb
 ;; Package-Requires: (
 ;;     (emacs   "30.1")
 ;;     (compat  "30.1")
 ;;     (cond-let "0.2")
 ;;     (elx      "2.3")
 ;;     (llama    "1.0")
-;;     (magit    "4.4"))
+;;     (magit    "4.5"))
 
 ;; SPDX-License-Identifier: GPL-3.0-or-later
 
@@ -239,6 +239,18 @@ and must return a list of the same form.  The default function sorts
 the dependencies alphabetically, except that \"emacs\" and \"compat\"
 are placed before other dependencies.")
 
+;;;###autoload(put 'sisyphus-libraries 'safe-local-variable #'listp)
+(defvar-local sisyphus-libraries nil
+  "List of libraries in which copyright years are bumped.
+If nil, use the default set.  If t is a member of the list, also use
+the default set.")
+
+;;;###autoload(put 'sisyphus-org-manuals 'safe-local-variable #'listp)
+(defvar-local sisyphus-org-manuals nil
+  "List of manuals in Org format in which copyright years are bumped.
+If nil, use the default set.  If t is a member of the list, also use
+the default set.")
+
 ;;; Commands
 
 ;;;###autoload
@@ -302,16 +314,37 @@ With prefix argument NOCOMMIT, do not create a commit."
 ;;; Functions
 
 (defun sisyphus--list-libs ()
-  (seq-remove
-   (##string-match-p "\\(\\`\\.\\|-autoloads\\.el\\'\\|-pkg.el\\'\\)"
-                     (file-name-nondirectory %))
-   (directory-files (if (file-directory-p "lisp") "lisp" ".") t "\\.el\\'")))
+  (let ((files (seq-remove
+                (##string-match-p
+                 "\\(\\`\\.\\|-autoloads\\.el\\'\\|-pkg.el\\'\\)"
+                 (file-name-nondirectory %))
+                (directory-files
+                 (if (file-directory-p "lisp") "lisp" ".") t "\\.el\\'"))))
+    (cond ((not sisyphus-libraries) files)
+          ((memq t sisyphus-libraries)
+           (delq t (nconc files sisyphus-libraries)))
+          (sisyphus-libraries))))
+
+(defun sisyphus--list-tests ()
+  (cond-let
+    ((file-directory-p "test")
+     (directory-files "test" t "\\.el\\'"))
+    [[file (format "%s-tests.el"
+                   (file-name-nondirectory
+                    (directory-file-name default-directory)))]]
+    ((file-exists-p file)
+     (list file))))
 
 (defun sisyphus--list-orgs ()
-  (seq-remove
-   (##string-match-p "\\`\\(\\.\\|README.org\\'\\)"
-                     (file-name-nondirectory %))
-   (directory-files (if (file-directory-p "docs") "docs" ".") t "\\.org\\'")))
+  (let ((files (seq-remove
+                (##string-match-p "\\`\\(\\.\\|README.org\\'\\)"
+                                  (file-name-nondirectory %))
+                (directory-files
+                 (if (file-directory-p "docs") "docs" ".") t "\\.org\\'"))))
+    (cond ((not sisyphus-org-manuals) files)
+          ((memq t sisyphus-org-manuals)
+           (delq t (nconc files sisyphus-org-manuals)))
+          (sisyphus-org-manuals))))
 
 (defun sisyphus--package-name ()
   (file-name-nondirectory (directory-file-name (magit-toplevel))))
@@ -384,26 +417,26 @@ With prefix argument NOCOMMIT, do not create a commit."
                   (today (format-time-string "%F")))
               (goto-char (line-beginning-position))
               (cond
-               (stub
-                (sisyphus--bump-changelog-insert-heading version "UNRELEASED"))
-               ((equal vers prev)
-                (sisyphus--bump-changelog-insert-heading version today)
-                (setq err "CHANGELOG entry missing; inserting stub"))
-               ((equal vers version)
-                (when (and (not (equal date today))
-                           (match-beginning 2))
-                  (replace-match today nil t nil 2)))
-               ((y-or-n-p
-                 (format "%sCHANGELOG version is %s, change%s to %s?"
-                         (if prev (format "Previous version is %s, " prev) "")
-                         vers
-                         (if prev " latter" "")
-                         version))
-                (delete-region (point) (line-end-position))
-                (when (re-search-forward "\\=\n+" nil t)
-                  (delete-region (match-beginning 0) (match-end 0)))
-                (sisyphus--bump-changelog-insert-heading version today))
-               ((user-error "Abort"))))
+                (stub
+                 (sisyphus--bump-changelog-insert-heading version "UNRELEASED"))
+                ((equal vers prev)
+                 (sisyphus--bump-changelog-insert-heading version today)
+                 (setq err "CHANGELOG entry missing; inserting stub"))
+                ((equal vers version)
+                 (when (and (not (equal date today))
+                            (match-beginning 2))
+                   (replace-match today nil t nil 2)))
+                ((y-or-n-p
+                  (format "%sCHANGELOG version is %s, change%s to %s?"
+                          (if prev (format "Previous version is %s, " prev) "")
+                          vers
+                          (if prev " latter" "")
+                          version))
+                 (delete-region (point) (line-end-position))
+                 (when (re-search-forward "\\=\n+" nil t)
+                   (delete-region (match-beginning 0) (match-end 0)))
+                 (sisyphus--bump-changelog-insert-heading version today))
+                ((user-error "Abort"))))
           (user-error "Unsupported CHANGELOG format")))
       (when err
         (magit-refresh)
@@ -487,10 +520,14 @@ With prefix argument NOCOMMIT, do not create a commit."
                              deps " ")))))))
 
 (defun sisyphus--bump-copyright ()
-  (dolist (lib (sisyphus--list-libs))
-    (sisyphus--bump-copyright-lib lib))
+  (dolist (file (nconc (sisyphus--list-libs)
+                       (sisyphus--list-tests)))
+    (sisyphus--bump-copyright-lib file))
   (when (sisyphus--list-orgs)
-    (magit-call-process "make" "clean" "texi" "all")))
+    (let ((file (expand-file-name "docs/.orgconfig")))
+      (when (file-exists-p file)
+        (sisyphus--bump-copyright-lib file)))
+    (magit-call-process "make" "texi")))
 
 (defun sisyphus--bump-copyright-lib (file)
   (sisyphus--with-file file
@@ -548,6 +585,9 @@ With prefix argument NOCOMMIT, do not create a commit."
 (provide 'sisyphus)
 ;; Local Variables:
 ;; indent-tabs-mode: nil
+;; lisp-indent-local-overrides: (
+;;   (cond . 0)
+;;   (interactive . 0))
 ;; read-symbol-shorthands: (
 ;;   ("and-let"      . "cond-let--and-let")
 ;;   ("if-let"       . "cond-let--if-let")
